@@ -92,7 +92,7 @@ pub struct Initial {
     #[serde(default)]
     user: Option<String>,
     #[serde(default)]
-    react_on_fail: bool,
+    react_to_fail: bool,
     #[serde(
         serialize_with = "crate::tools::serialize_atomic_bool",
         deserialize_with = "crate::tools::deserialize_atomic_bool"
@@ -114,7 +114,7 @@ impl Initial {
         config: Option<&Value>,
         workers: u32,
         user: Option<&str>,
-        react_on_fail: bool,
+        react_to_fail: bool,
     ) -> Self {
         Self {
             config_version: SERVICE_CONFIG_VERSION,
@@ -129,7 +129,7 @@ impl Initial {
             config: config.map(Clone::clone),
             workers,
             user: user.map(ToOwned::to_owned),
-            react_on_fail,
+            react_to_fail,
             fail_mode: atomic::AtomicBool::new(false),
         }
     }
@@ -317,15 +317,15 @@ impl Initial {
         }
     }
     #[inline]
-    pub fn can_rof(&self) -> bool {
-        self.react_on_fail
+    pub fn can_rtf(&self) -> bool {
+        self.react_to_fail
     }
     #[inline]
     pub fn is_mode_normal(&self) -> bool {
         !self.fail_mode.load(atomic::Ordering::SeqCst)
     }
     #[inline]
-    pub fn is_mode_rof(&self) -> bool {
+    pub fn is_mode_rtf(&self) -> bool {
         self.fail_mode.load(atomic::Ordering::SeqCst)
     }
     #[inline]
