@@ -555,7 +555,11 @@ async fn extend_string_value(val: String, op: &crate::op::Op, base: &Path) -> ER
                 let s = pipe!();
                 Ok(Value::String(s.trim_end().to_string()))
             }
-            _ => Ok(Value::String(val)),
+            _ => Ok(Value::String(if s.starts_with('^') {
+                s.to_owned()
+            } else {
+                val
+            })),
         }
     } else {
         Ok(Value::String(val))
